slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPJDProjection

The type of projection to be used in the Jacobi-Davidson solver

### Synopsis

    typedef enum { PEP_JD_PROJECTION_HARMONIC,
                   PEP_JD_PROJECTION_ORTHOGONAL } PEPJDProjection;

### See Also

PEPJDSetProjection()

### Level

intermediate

### Location

include/slepcpep.h
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages